
# $rcs = ' $Id: Search.pm,v 1.9 2010-03-06 13:33:22 Martin Exp $ ' ;

package WWW::Ebay::Search;

use strict;
use warnings;

use WWW::Search::Ebay;

use vars qw( @ISA );
@ISA = qw( WWW::Search::Ebay );

1;

__END__

=head1 AUTHOR

Martin 'Kingpin' Thurn, C<mthurn at cpan.org>, L<http://tinyurl.com/nn67z>.

=cut


